@@ -2,6 +2,7 @@ import os
 import re
 import yaml
 import json
+import traceback
 
 # Every file matching the pattern gets thrown into a Page object
 class Page():
@@ -11,16 +12,19 @@ class Page():
         self.relative_path = os.path.join(root.replace(input_dir, "", 1), fileName)
         self.output_filename = ""
         self.output_path = ""
-        # self.file_contents = ""
-        # self.mtime = 0
-        # self.meta = {}
         self.file_contents = self.get_contents(self.file_path)
         self.mtime = self.get_modified_time()
         self.meta = self.get_metadata(self.file_contents)
 
     def get_contents(self, file_path):
         source_file = open(file_path, 'r')
-        file_contents = source_file.read().decode('utf8')
+        file_contents = ""
+        try:
+            file_contents = source_file.read().decode('utf8')
+        except:
+            print "\033[31mTrouble reading %s\033[0m" % (source_file)
+            traceback.print_exc() 
+        
         return file_contents
 
     def get_metadata(self, file_contents):
@@ -37,15 +41,21 @@ class Page():
 
         page_vars = {"yk_data":{"title": None, "template": None, "description": None}}
         default_content = {"data":""}
+        json_data = {}
 
-        json_data = json.loads(file_contents)
+        try:
+            json_data = json.loads(file_contents)
+        except:
+            print "\033[31mCouldn't decode %s\033[0m" % (self.file_path)
+            traceback.print_exc() 
 
         if "yk_data" in json_data:
             page_vars.update(json_data["yk_data"])
-
-        # For backwards compatibility with old stuff
-        page_vars["extends"] = page_vars["template"]
+            page_vars["extends"] = page_vars["template"]
+        else:
+            page_vars["extends"] = page_vars["yk_data"]["template"]
         
+
         if "data" in json_data:
             self.file_contents = json_data["data"]
         else:
